@@ -2,8 +2,8 @@
 from relevantpackage.relevantpackage import Relevantpackage
 
 __author__ = 'E.Taskesen'
-__email__ = 'name@gmail.com'
-__version__ = '0.1.1'
+__email__ = 'erdogant@gmail.com'
+__version__ = '0.1.2'
 
 # module level doc-string
 __doc__ = """
